# Pacote PIX

Principais dependências:

![](https://img.shields.io/badge/Python-v3.0+-blue)

Pacote pela integração do meio de pagamento PIX.

## Projetos relacionados

- Sem dependência de outro projeto.

## Variáveis de Ambiente Necessárias

- Não se aplica.

## Como configurar o Pacote em Serviço

### Instalação

Comando:

```sh
pip install lins-pix
```

### Importação

- **XX**: Descricao
- **YY**: Descricao

Código:

```python
from lins-pix import xxx
```

## Utilização

### 1) XXX

#### Exemplo:

Código:

```python
meu codigo
```

#### Parâmetros:

- Descricao

#### 2) Utilização no Programa Principal 

- Descricao

Exemplo:

```python
meu codigo
```